pro mnr_frm_fix,index,data

;+
; NAME
;	mnr_frm_fix
; PURPOSE
;	SXT images often have minor frames of data missing.
;	Usually these are zeroes.  Occasionally the missing
;	minor frames are set to 170 DN.  The purpose of this
;	program is to identify these minor frames in SXT
;	compressed images and set the 170 values to zero in
;	the missing minor frames.
; CALLING SEQUENCE
;	mnr_frm_fix,index,data
; INPUT
;	index, SXT index structure
;	data, raw, compressed, SXT image or data cube
;	   (mixed resoutions, image sizes, etc., are OK)
; OUTPUT
;	data cube with missinf minor frames set to zero
; RESTRICTIONS
;	Only works for sxt_compressed images.
; HISTORY
;	30-Jul-2004 LWA
;-

for i=0,n_elements(index)-1 do begin
   nx=gt_shape(index(i),/x)
   ny=gt_shape(index(i),/y)
   xsum=total(data(0:nx-1,0:ny-1,i),1)/nx
   jj=where(xsum eq 170,njj)
   ; Make certain that entire row shows 170 DN.
   if njj gt 0 then begin
      for j=0,n_elements(jj)-1 do begin
         if (min(data(0:nx-1,jj,i)) eq max(data(0:nx-1,jj,i)) $
	    and min(data(0:nx-1,jj,i)) eq 170) then $
	    data(0:nx-1,jj,i)=0
       endfor
    endif
endfor

end
